pub unsafe fn av_frame_to_owned_audio_frame(
av_frame: *const AVFrame,
time_base: Timebase,
limits: FrameLimits,
) -> Result<AudioFrame<SampleFormat, ChannelLayoutDescription, AudioFrameExtra, FfmpegBytes>, ConvertError>Expand description
av_frame_to_audio_frame on the owned lane, which copies every byte it
reads and therefore has no aliasing obligation.
Safety
The source must be live for the duration of the call.