FfmpegAudioStreamDecoder

Struct FfmpegAudioStreamDecoder 

pub struct FfmpegAudioStreamDecoder { /* private fields */ }
mediadecode::AudioStreamDecoder impl wrapping ffmpeg::decoder::Audio.

Implementations

Source

impl FfmpegAudioStreamDecoder

pub fn open( parameters: Parameters, time_base: Timebase, ) -> Result<Self, AudioDecodeError>

Opens an audio decoder for the given codec parameters.

pub const fn time_base(&self) -> Timebase

Returns the time base associated with the source stream.

pub const fn inner(&self) -> &Audio

Borrow the wrapped ffmpeg::decoder::Audio (e.g. to query channels() / rate() / format()).