pub unsafe fn av_frame_to_audio_frame(
av_frame: *const AVFrame,
time_base: Timebase,
limits: FrameLimits,
) -> Result<AudioFrame<SampleFormat, ChannelLayoutDescription, AudioFrameExtra, FfmpegBuffer>, ConvertError>Expand description
[av_frame_to_audio_frame_as] on the view lane.
Safety
As the crate-private worker: a live source for the duration of the call, and โ on this lane โ no handle capable of mutating its buffers may outlive the returned carriers.