pub unsafe fn av_subtitle_to_subtitle_frame(
av_subtitle: *const AVSubtitle,
time_base: Timebase,
) -> Result<SubtitleFrame<SubtitleFrameExtra, FfmpegBuffer>, ConvertError>Expand description
[av_subtitle_to_subtitle_frame_as] on the view lane.
Safety
As the crate-private worker: a live source for the duration of the call, and โ on this lane โ no handle capable of mutating its buffers may outlive the returned carriers.