pub enum DemuxError {
Ffmpeg(Error),
AttachmentAlloc(AttachmentAlloc),
ParametersMissing(ParametersMissing),
ParametersAlloc(ParametersAlloc),
ParametersCopy(ParametersCopy),
PacketBuffer(PacketBuffer),
ReaderPanic(ReaderPanic),
}Expand description
Errors from FfmpegDemuxer.
Variants
Ffmpeg(Error)
The wrapped libavformat call reported an error — open, read or seek.
AttachmentAlloc(AttachmentAlloc)
FFmpeg refused a buffer allocation while capturing an attachment’s payload at open time.
ParametersMissing(ParametersMissing)
Codec parameters arrived that were never allocated.
ParametersAlloc(ParametersAlloc)
Codec parameters for a track could not be allocated.
ParametersCopy(ParametersCopy)
Copying a track’s codec parameters failed part way.
PacketBuffer(PacketBuffer)
A packet’s payload could not be referenced — the bytes are there and this layer could not carry them.
ReaderPanic(ReaderPanic)
The Read + Seek source given to
FfmpegDemuxer::open_reader panicked inside a libavformat
callback.
Implementations
Sourceimpl DemuxError
impl DemuxError
Sourcepub const fn is_ffmpeg(&self) -> bool
pub const fn is_ffmpeg(&self) -> bool
Returns true if this value is of type Ffmpeg. Returns false otherwise
Sourcepub const fn is_attachment_alloc(&self) -> bool
pub const fn is_attachment_alloc(&self) -> bool
Returns true if this value is of type AttachmentAlloc. Returns false otherwise
Sourcepub const fn is_parameters_missing(&self) -> bool
pub const fn is_parameters_missing(&self) -> bool
Returns true if this value is of type ParametersMissing. Returns false otherwise
Sourcepub const fn is_parameters_alloc(&self) -> bool
pub const fn is_parameters_alloc(&self) -> bool
Returns true if this value is of type ParametersAlloc. Returns false otherwise
Sourcepub const fn is_parameters_copy(&self) -> bool
pub const fn is_parameters_copy(&self) -> bool
Returns true if this value is of type ParametersCopy. Returns false otherwise
Sourcepub const fn is_packet_buffer(&self) -> bool
pub const fn is_packet_buffer(&self) -> bool
Returns true if this value is of type PacketBuffer. Returns false otherwise
Sourcepub const fn is_reader_panic(&self) -> bool
pub const fn is_reader_panic(&self) -> bool
Returns true if this value is of type ReaderPanic. Returns false otherwise
Sourceimpl DemuxError
impl DemuxError
Sourcepub fn unwrap_ffmpeg(self) -> Error
pub fn unwrap_ffmpeg(self) -> Error
Unwraps this value to the DemuxError::Ffmpeg variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_ffmpeg_ref(&self) -> &Error
pub fn unwrap_ffmpeg_ref(&self) -> &Error
Unwraps this reference to the DemuxError::Ffmpeg variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_ffmpeg_mut(&mut self) -> &mut Error
pub fn unwrap_ffmpeg_mut(&mut self) -> &mut Error
Unwraps this mutable reference to the DemuxError::Ffmpeg variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_attachment_alloc(self) -> AttachmentAlloc
pub fn unwrap_attachment_alloc(self) -> AttachmentAlloc
Unwraps this value to the DemuxError::AttachmentAlloc variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_attachment_alloc_ref(&self) -> &AttachmentAlloc
pub fn unwrap_attachment_alloc_ref(&self) -> &AttachmentAlloc
Unwraps this reference to the DemuxError::AttachmentAlloc variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_attachment_alloc_mut(&mut self) -> &mut AttachmentAlloc
pub fn unwrap_attachment_alloc_mut(&mut self) -> &mut AttachmentAlloc
Unwraps this mutable reference to the DemuxError::AttachmentAlloc variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_parameters_missing(self) -> ParametersMissing
pub fn unwrap_parameters_missing(self) -> ParametersMissing
Unwraps this value to the DemuxError::ParametersMissing variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_parameters_missing_ref(&self) -> &ParametersMissing
pub fn unwrap_parameters_missing_ref(&self) -> &ParametersMissing
Unwraps this reference to the DemuxError::ParametersMissing variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_parameters_missing_mut(&mut self) -> &mut ParametersMissing
pub fn unwrap_parameters_missing_mut(&mut self) -> &mut ParametersMissing
Unwraps this mutable reference to the DemuxError::ParametersMissing variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_parameters_alloc(self) -> ParametersAlloc
pub fn unwrap_parameters_alloc(self) -> ParametersAlloc
Unwraps this value to the DemuxError::ParametersAlloc variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_parameters_alloc_ref(&self) -> &ParametersAlloc
pub fn unwrap_parameters_alloc_ref(&self) -> &ParametersAlloc
Unwraps this reference to the DemuxError::ParametersAlloc variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_parameters_alloc_mut(&mut self) -> &mut ParametersAlloc
pub fn unwrap_parameters_alloc_mut(&mut self) -> &mut ParametersAlloc
Unwraps this mutable reference to the DemuxError::ParametersAlloc variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_parameters_copy(self) -> ParametersCopy
pub fn unwrap_parameters_copy(self) -> ParametersCopy
Unwraps this value to the DemuxError::ParametersCopy variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_parameters_copy_ref(&self) -> &ParametersCopy
pub fn unwrap_parameters_copy_ref(&self) -> &ParametersCopy
Unwraps this reference to the DemuxError::ParametersCopy variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_parameters_copy_mut(&mut self) -> &mut ParametersCopy
pub fn unwrap_parameters_copy_mut(&mut self) -> &mut ParametersCopy
Unwraps this mutable reference to the DemuxError::ParametersCopy variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_packet_buffer(self) -> PacketBuffer
pub fn unwrap_packet_buffer(self) -> PacketBuffer
Unwraps this value to the DemuxError::PacketBuffer variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_packet_buffer_ref(&self) -> &PacketBuffer
pub fn unwrap_packet_buffer_ref(&self) -> &PacketBuffer
Unwraps this reference to the DemuxError::PacketBuffer variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_packet_buffer_mut(&mut self) -> &mut PacketBuffer
pub fn unwrap_packet_buffer_mut(&mut self) -> &mut PacketBuffer
Unwraps this mutable reference to the DemuxError::PacketBuffer variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_reader_panic(self) -> ReaderPanic
pub fn unwrap_reader_panic(self) -> ReaderPanic
Unwraps this value to the DemuxError::ReaderPanic variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_reader_panic_ref(&self) -> &ReaderPanic
pub fn unwrap_reader_panic_ref(&self) -> &ReaderPanic
Unwraps this reference to the DemuxError::ReaderPanic variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_reader_panic_mut(&mut self) -> &mut ReaderPanic
pub fn unwrap_reader_panic_mut(&mut self) -> &mut ReaderPanic
Unwraps this mutable reference to the DemuxError::ReaderPanic variant.
Panics if this value is of any other type.
Sourceimpl DemuxError
impl DemuxError
Sourcepub fn try_unwrap_ffmpeg(self) -> Result<Error, TryUnwrapError<Self>>
pub fn try_unwrap_ffmpeg(self) -> Result<Error, TryUnwrapError<Self>>
Attempts to unwrap this value to the DemuxError::Ffmpeg variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_ffmpeg_ref(&self) -> Result<&Error, TryUnwrapError<&Self>>
pub fn try_unwrap_ffmpeg_ref(&self) -> Result<&Error, TryUnwrapError<&Self>>
Attempts to unwrap this reference to the DemuxError::Ffmpeg variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_ffmpeg_mut(
&mut self,
) -> Result<&mut Error, TryUnwrapError<&mut Self>>
pub fn try_unwrap_ffmpeg_mut( &mut self, ) -> Result<&mut Error, TryUnwrapError<&mut Self>>
Attempts to unwrap this mutable reference to the DemuxError::Ffmpeg variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_attachment_alloc(
self,
) -> Result<AttachmentAlloc, TryUnwrapError<Self>>
pub fn try_unwrap_attachment_alloc( self, ) -> Result<AttachmentAlloc, TryUnwrapError<Self>>
Attempts to unwrap this value to the DemuxError::AttachmentAlloc variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_attachment_alloc_ref(
&self,
) -> Result<&AttachmentAlloc, TryUnwrapError<&Self>>
pub fn try_unwrap_attachment_alloc_ref( &self, ) -> Result<&AttachmentAlloc, TryUnwrapError<&Self>>
Attempts to unwrap this reference to the DemuxError::AttachmentAlloc variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_attachment_alloc_mut(
&mut self,
) -> Result<&mut AttachmentAlloc, TryUnwrapError<&mut Self>>
pub fn try_unwrap_attachment_alloc_mut( &mut self, ) -> Result<&mut AttachmentAlloc, TryUnwrapError<&mut Self>>
Attempts to unwrap this mutable reference to the DemuxError::AttachmentAlloc variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_parameters_missing(
self,
) -> Result<ParametersMissing, TryUnwrapError<Self>>
pub fn try_unwrap_parameters_missing( self, ) -> Result<ParametersMissing, TryUnwrapError<Self>>
Attempts to unwrap this value to the DemuxError::ParametersMissing variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_parameters_missing_ref(
&self,
) -> Result<&ParametersMissing, TryUnwrapError<&Self>>
pub fn try_unwrap_parameters_missing_ref( &self, ) -> Result<&ParametersMissing, TryUnwrapError<&Self>>
Attempts to unwrap this reference to the DemuxError::ParametersMissing variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_parameters_missing_mut(
&mut self,
) -> Result<&mut ParametersMissing, TryUnwrapError<&mut Self>>
pub fn try_unwrap_parameters_missing_mut( &mut self, ) -> Result<&mut ParametersMissing, TryUnwrapError<&mut Self>>
Attempts to unwrap this mutable reference to the DemuxError::ParametersMissing variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_parameters_alloc(
self,
) -> Result<ParametersAlloc, TryUnwrapError<Self>>
pub fn try_unwrap_parameters_alloc( self, ) -> Result<ParametersAlloc, TryUnwrapError<Self>>
Attempts to unwrap this value to the DemuxError::ParametersAlloc variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_parameters_alloc_ref(
&self,
) -> Result<&ParametersAlloc, TryUnwrapError<&Self>>
pub fn try_unwrap_parameters_alloc_ref( &self, ) -> Result<&ParametersAlloc, TryUnwrapError<&Self>>
Attempts to unwrap this reference to the DemuxError::ParametersAlloc variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_parameters_alloc_mut(
&mut self,
) -> Result<&mut ParametersAlloc, TryUnwrapError<&mut Self>>
pub fn try_unwrap_parameters_alloc_mut( &mut self, ) -> Result<&mut ParametersAlloc, TryUnwrapError<&mut Self>>
Attempts to unwrap this mutable reference to the DemuxError::ParametersAlloc variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_parameters_copy(
self,
) -> Result<ParametersCopy, TryUnwrapError<Self>>
pub fn try_unwrap_parameters_copy( self, ) -> Result<ParametersCopy, TryUnwrapError<Self>>
Attempts to unwrap this value to the DemuxError::ParametersCopy variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_parameters_copy_ref(
&self,
) -> Result<&ParametersCopy, TryUnwrapError<&Self>>
pub fn try_unwrap_parameters_copy_ref( &self, ) -> Result<&ParametersCopy, TryUnwrapError<&Self>>
Attempts to unwrap this reference to the DemuxError::ParametersCopy variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_parameters_copy_mut(
&mut self,
) -> Result<&mut ParametersCopy, TryUnwrapError<&mut Self>>
pub fn try_unwrap_parameters_copy_mut( &mut self, ) -> Result<&mut ParametersCopy, TryUnwrapError<&mut Self>>
Attempts to unwrap this mutable reference to the DemuxError::ParametersCopy variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_packet_buffer(
self,
) -> Result<PacketBuffer, TryUnwrapError<Self>>
pub fn try_unwrap_packet_buffer( self, ) -> Result<PacketBuffer, TryUnwrapError<Self>>
Attempts to unwrap this value to the DemuxError::PacketBuffer variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_packet_buffer_ref(
&self,
) -> Result<&PacketBuffer, TryUnwrapError<&Self>>
pub fn try_unwrap_packet_buffer_ref( &self, ) -> Result<&PacketBuffer, TryUnwrapError<&Self>>
Attempts to unwrap this reference to the DemuxError::PacketBuffer variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_packet_buffer_mut(
&mut self,
) -> Result<&mut PacketBuffer, TryUnwrapError<&mut Self>>
pub fn try_unwrap_packet_buffer_mut( &mut self, ) -> Result<&mut PacketBuffer, TryUnwrapError<&mut Self>>
Attempts to unwrap this mutable reference to the DemuxError::PacketBuffer variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_reader_panic(
self,
) -> Result<ReaderPanic, TryUnwrapError<Self>>
pub fn try_unwrap_reader_panic( self, ) -> Result<ReaderPanic, TryUnwrapError<Self>>
Attempts to unwrap this value to the DemuxError::ReaderPanic variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_reader_panic_ref(
&self,
) -> Result<&ReaderPanic, TryUnwrapError<&Self>>
pub fn try_unwrap_reader_panic_ref( &self, ) -> Result<&ReaderPanic, TryUnwrapError<&Self>>
Attempts to unwrap this reference to the DemuxError::ReaderPanic variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_reader_panic_mut(
&mut self,
) -> Result<&mut ReaderPanic, TryUnwrapError<&mut Self>>
pub fn try_unwrap_reader_panic_mut( &mut self, ) -> Result<&mut ReaderPanic, TryUnwrapError<&mut Self>>
Attempts to unwrap this mutable reference to the DemuxError::ReaderPanic variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.